/*
 Project author:     ModelTheme
 File name:          Car Rental Search Form For Affiliates JS
*/
(function ($) {
    'use strict';
    $(document).ready(function() {
        $(".mt-rental-affiliate-different-location-input").on("change", function() {
            const checkbox = $(this);
            const wrapperId = checkbox.attr("id") + "-wrapper";
            const wrapper = $("#" + wrapperId);

            if (checkbox.prop("checked")) {
                wrapper.addClass('show-wrapper');
            } else {
                wrapper.removeClass('show-wrapper');
            }

            $(".mt-rental-affiliate-pick-up-location-search-wrapper.different-location-input").not(wrapper).removeClass('show-wrapper');
        });
        $(".mt-rental-affiliate-driver-age-input").each(function() {
            $(this).on("change", function() {
                const ageFields = $(this).closest(".mt-rental-affiliate-check").find(".driver-age");

                if (ageFields.length) {
                    if ($(this).prop("checked")) {
                        ageFields.css("display", "none");
                    } else {
                        ageFields.css("display", "block");
                    }
                }
            });
        });
        $(".mt-rental-affiliate-date-select-wrapper").each(function() {
            const wrapperId = $(this).find("input").attr("id");
            $("#" + wrapperId).flatpickr({
                mode: 'range',
                dateFormat: "Y-m-d",
                onClose: function(selectedDates, dateStr, instance) {
                    const startDate = selectedDates[0];
                    const endDate = selectedDates[selectedDates.length - 1];
                    
                    // Set attributes for pick-up date
                    $("#" + wrapperId).attr({
                        "puDay": startDate.getDate(),
                        "puMonth": startDate.getMonth() + 1, 
                        "puYear": startDate.getFullYear(),
                        
                        "doDay": endDate.getDate(),
                        "doMonth": endDate.getMonth() + 1, 
                        "doYear": endDate.getFullYear()
                    });
                }
            });
        });

        $(".mt-rental-affiliate-time-select-wrapper").each(function() {
            const wrapperId = $(this).find("input").attr("id");
            const inputElement = $("#" + wrapperId);

            inputElement.flatpickr({
                enableTime: true,
                noCalendar: true,
                time_24hr: true,
                dateFormat: "H:i",
                onClose: function(selectedDates, dateStr, instance) {
                    const selectedHour = instance.selectedDates[0].getHours();
                    const selectedMinute = instance.selectedDates[0].getMinutes();

                    inputElement.attr({
                        "puHour": selectedHour,
                        "puMinute": selectedMinute,
                        "doHour": selectedHour,
                        "doMinute": selectedMinute
                    });
                }
            });
        });
        $(".mt-rental-affiliate-search-element-submit").click(function(e) {
            e.preventDefault();

            const form = $(this).closest("form");
            const queryParams = [];

            // Fetch values for locationName, dropLocationName, and driversAge
            let locationName = form.find("[name='locationName']").val();
            let dropLocationName = form.find("[name='dropLocationName']").val();
            const driversAge = form.find("[name='driversAge']").val(); // Fetch driversAge value

            // If dropLocationName is not set, set it to locationName
            if (!dropLocationName.trim()) {
                dropLocationName = locationName;
            }

            // Collect values from hidden input fields
            const hiddenInputs = form.find("input[type='hidden']");
            hiddenInputs.each(function() {
                const name = $(this).attr("name");
                const value = $(this).val();
                queryParams.push(`${name}=${encodeURIComponent(value)}`);
            });

            // Define a function to handle the rest of the logic after fetching coordinates
            function continueProcess(locationCoordinates, dropLocationCoordinates) {
                // Push locationName, dropLocationName, and driversAge to queryParams
                queryParams.push("locationName=" + encodeURIComponent(locationName));
                queryParams.push("dropLocationName=" + encodeURIComponent(dropLocationName));
                queryParams.push("driversAge=" + encodeURIComponent(driversAge));
                // Push location coordinates to queryParams
                queryParams.push(`coordinates=${encodeURIComponent(locationCoordinates)}`);
                queryParams.push(`dropCoordinates=${encodeURIComponent(dropLocationCoordinates)}`);
                // Fetch values for the first date input (assuming it's the pick-up date)
                const firstDateInput = form.find(".mt-rental-affiliate-date-input").first();
                const puDay = firstDateInput.attr("puDay");
                const puMonth = firstDateInput.attr("puMonth");
                const puYear = firstDateInput.attr("puYear");

                queryParams.push(`puDay=${puDay}&puMonth=${puMonth}&puYear=${puYear}`);

                // Fetch values for the pick-up time input
                const pickUpTimeInput = form.find(".mt-rental-affiliate-time-input[puHour][puMinute]");
                const puHour = pickUpTimeInput.attr("puHour");
                const puMinute = pickUpTimeInput.attr("puMinute");

                queryParams.push(`puHour=${puHour}&puMinute=${puMinute}`);

                // Fetch values for the last date input (assuming it's the drop-off date)
                const lastDateInput = form.find(".mt-rental-affiliate-date-input").last();
                const doDay = lastDateInput.attr("doDay");
                const doMonth = lastDateInput.attr("doMonth");
                const doYear = lastDateInput.attr("doYear");

                queryParams.push(`doDay=${doDay}&doMonth=${doMonth}&doYear=${doYear}`);

                // Fetch values for the drop-off time input
                const dropOffTimeInput = form.find(".mt-rental-affiliate-time-input[doHour][doMinute]");
                const doHour = dropOffTimeInput.attr("doHour");
                const doMinute = dropOffTimeInput.attr("doMinute");

                queryParams.push(`doHour=${doHour}&doMinute=${doMinute}`);

                // Construct the final URL
                const actionUrl = form.attr("action");
                const queryString = queryParams.join("&");
                const finalUrl = actionUrl + "&" + queryString;

                // Redirect to the final URL
                window.open(finalUrl, '_blank');
            }

            // Fetch pick-up location coordinates
            getLocationCoordinates(locationName, function(locationCoordinates) {
                // Fetch drop-off location coordinates
                getLocationCoordinates(dropLocationName, function(dropLocationCoordinates) {
                    continueProcess(locationCoordinates, dropLocationCoordinates);
                });
            });
        });
        function getLocationCoordinates(locationName, callback) {
            $.ajax({
                url: 'https://nominatim.openstreetmap.org/search',
                data: {
                    format: 'json',
                    q: locationName
                },
                method: 'GET',
                success: function (response) {
                    if (response && response.length > 0) {
                        var latitude = response[0].lat;
                        var longitude = response[0].lon;
                        var coordinates = latitude + ',' + longitude;
                        callback(coordinates);
                    } 
                }
            });
        }
    });
})(jQuery);