<?php
namespace Elementor;

class CRSFFA_Widget extends Widget_Base {

    public function get_style_depends() {
        wp_enqueue_style( 'crsffa-custom', plugins_url( 'assets/css/custom.css', __FILE__ ), array(), '1.0.0', 'all' );
        wp_enqueue_style( 'flatpickr', plugins_url( 'assets/css/flatpickr.min.css', __FILE__ ), array(), '1.0.0', 'all' );
        return [
            'crsffa-custom',
            'flatpickr',
        ];
    }
    public function get_script_depends() {
        
        wp_enqueue_script( 'flatpickr', plugins_url( 'assets/js/flatpickr.js', __FILE__ ), array(), '4.6.13', 'all' );
        wp_enqueue_script( 'crsffa-custom', plugins_url( 'assets/js/custom.js', __FILE__ ), array(), '1.0.0', 'all' );
        
        return [ 'flatpickr', 'crsffa-custom'];
    }
	
	public function get_name() {
		return 'crsffa-forms';
	}
	 
	public function get_title() {
		return esc_html__('Car Rental Search Forms for Affiliates', 'crsffa');
	}
	
	public function get_icon() {
		return 'eicon-menu-toggle';
	}
	
	public function get_categories() {
		return [ 'modeltheme-widgets' ];
	}

    protected function register_controls() {

        $this->start_controls_section(
            'section_title',
            [
                'label' => esc_html__( 'General Options', 'crsffa' ),
            ]
        );
        $this->add_control(
            'select_search',
            [
                'type' => \Elementor\Controls_Manager::SELECT,
                'label' => esc_html__( 'Select Search', 'crsffa' ),
                'options' => [
                    'default' => esc_html__( 'Default', 'crsffa' ),
                    'booking_search' => esc_html__( 'Booking Search', 'crsffa' ),
                    'kiwi_search' => esc_html__( 'Kiwi Search', 'crsffa' ),
                ],
                'default' => 'booking_search',
            ]
        );
        $this->add_control(
            'affiliate_id',
            [
                'label' => esc_html__('Affiliate ID', 'crsffa'),
                'type' => Controls_Manager::TEXT,
                'description ' => esc_html__('Affiliate ID"s', 'crsffa'),
            ]
        );
        $this->add_control(
            'text_drivers_age',
            [
                'label' => esc_html__('Drivers Age', 'crsffa'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__( 'Drivers Age', 'crsffa' ),
                'description ' => esc_html__('Drivers Age', 'crsffa'),
            ]
        );
        $this->add_control(
            'drivers_age',
            [
                'label' => esc_html__( 'Drivers Age', 'crsffa' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => '30',
            ]
        );
        $this->add_control(
            'show_different_location',
            [
                'label' => esc_html__( 'Show Different Location', 'crsffa' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'crsffa' ),
                'label_off' => esc_html__( 'Hide', 'crsffa' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );
        $this->add_control(
            'text_pick_up',
            [
                'label' => esc_html__('Pick-up location', 'crsffa'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__( 'Pick-up Location', 'crsffa' ),
                'description ' => esc_html__('Pick-up Location', 'crsffa'),
            ]
        );
        $this->add_control(
            'placeholder_pick_up',
            [
                'label' => esc_html__('Choose a location ...', 'crsffa'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__( 'Choose a location ...', 'crsffa' ),
                'description ' => esc_html__('Custom text for "Choose a location ..."', 'crsffa'),
            ]
        );
        $this->add_control(
            'text_date',
            [
                'label' => esc_html__('Date', 'crsffa'),
                'type' => Controls_Manager::TEXT,
                'description ' => esc_html__('Date', 'crsffa'),
                'default' => esc_html__( 'Date', 'crsffa' ),
            ]
        );
        $this->add_control(
            'placeholder_date',
            [
                'label' => esc_html__('Select date ...', 'crsffa'),
                'type' => Controls_Manager::TEXT,
                'description ' => esc_html__('Select date ...', 'crsffa'),
                'default' => esc_html__( 'Select date ...', 'crsffa' ),
            ]
        );  
        $this->add_control(
            'text_pick_up_time',
            [
                'label' => esc_html__('Pick-up Time', 'crsffa'),
                'type' => Controls_Manager::TEXT,
                'description ' => esc_html__('Pick-up Time', 'crsffa'),
                'default' => esc_html__( 'Pick-up Time', 'crsffa' ),
            ]
        );
        $this->add_control(
            'placeholder_pick_up_time',
            [
                'label' => esc_html__('Placeholder pick-up time', 'crsffa'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__( '--:--', 'crsffa' ),
                'description ' => esc_html__('--:--', 'crsffa'),
            ]
        );
        $this->add_control(
            'text_dropp_off_time',
            [
                'label' => esc_html__('Drop-off Time', 'crsffa'),
                'type' => Controls_Manager::TEXT,
                'description ' => esc_html__('Drop-off Time', 'crsffa'),
                'default' => esc_html__( 'Drop-off Time', 'crsffa' ),
            ]
        );
        $this->add_control(
            'placeholder_dropp_off_time',
            [
                'label' => esc_html__('Placeholder dropp-odd time', 'crsffa'),
                'type' => Controls_Manager::TEXT,
                'description ' => esc_html__('--:--', 'crsffa'),
                'default' => esc_html__( '--:--', 'crsffa' ),
            ]
        );
        $this->add_control(
            'submit_button_label',
            [
                'label' => esc_html__( 'Submit Button label', 'crsffa' ),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Enter Submit button label', 'crsffa' ),
                'default' => esc_html__( 'Search', 'crsffa' ),

            ]
        );
        $this->add_control(
            'bg_color',
            [
                'label' => esc_html__( 'Background Search', 'crsffa' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mt-rental-affiliate-search-element' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'btn_bg_color',
            [
                'label' => esc_html__( 'Background Button', 'crsffa' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mt-rental-affiliate-search-element-submit' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'btn_bg_hover_color',
            [
                'label' => esc_html__( 'Button Background Hover', 'crsffa' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mt-rental-affiliate-search-element-submit:hover' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'btn_color',
            [
                'label' => esc_html__( 'Button Text Color', 'crsffa' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mt-rental-affiliate-search-element-submit input[type="submit"]' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'btn_hover_color',
            [
                'label' => esc_html__( 'Button Text Color Hover', 'crsffa' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .mt-rental-affiliate-search-element-submit input[type="submit"]:hover' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_section();
    }
    
    protected function render() {
        $settings                       = $this->get_settings_for_display();
        $affiliate_id                   = $settings['affiliate_id'];
        $text_pick_up                   = $settings['text_pick_up'];
        $placeholder_pick_up            = $settings['placeholder_pick_up'];
        $text_date                      = $settings['text_date'];
        $placeholder_date               = $settings['placeholder_date'];
        $text_pick_up_time              = $settings['text_pick_up_time'];
        $placeholder_pick_up_time       = $settings['placeholder_pick_up_time'];
        $text_dropp_off_time            = $settings['text_dropp_off_time'];
        $placeholder_dropp_off_time     = $settings['placeholder_dropp_off_time'];
        $submit_button_label            = $settings['submit_button_label'];
        $select_search                  = $settings['select_search'];
        $drivers_age                    = $settings['drivers_age'];
        $text_drivers_age               = $settings['text_drivers_age'];

        $shortcode_content = '';
        $shortcode_content .= do_shortcode('[crsffa-builder-shortcode page_builder="elementor" 
            affiliate_id="'.esc_attr($affiliate_id).'"  
            text_pick_up="'.esc_html($text_pick_up).'"  
            placeholder_pick_up="'.esc_attr($placeholder_pick_up).'"  
            text_date="'.esc_html($text_date).'"  
            placeholder_date="'.esc_attr($placeholder_date).'"  
            text_pick_up_time="'.esc_html($text_pick_up_time).'"  
            placeholder_pick_up_time="'.esc_attr($placeholder_pick_up_time).'"  
            text_dropp_off_time="'.esc_html($text_dropp_off_time).'"  
            placeholder_dropp_off_time="'.esc_attr($placeholder_dropp_off_time).'"  
            select_search="'.esc_attr($select_search).'"  
            drivers_age="'.esc_attr($drivers_age).'"  
            text_drivers_age="'.esc_html($text_drivers_age).'"  
            submit_button_label="'.esc_attr($submit_button_label).'"]');

        echo  $shortcode_content;
    }
    protected function content_template() {
    }
}